@@ -1,5 +1,5 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "tmpl-mode" "1.0.0"
+(define-package "tmpl-mode" "20260103.1717"
   "Minor mode for \"tmpl\" template files."
   '((emacs "25.1"))
   :url "https://github.com/Lindydancer/tmpl-mode"
